@@ -14,7 +14,12 @@
 #' \link{multiSearchInGithubRepo} but has shorter name and
 #' different paramter's specification.
 #' 
-#' @param repo A character with GitHub user name and GitHub repository name separated by `/`.
+#' @param repo One of following:
+#' 
+#' A character with GitHub user name and GitHub repository name separated by `/`.
+#' 
+#' NULL in this case search will be performed in the default repo.
+#' 
 #' @param patterns  A character vector of tags. Only artifacts that 
 #' contain all tags are returned.  
 #' 
@@ -33,20 +38,30 @@
 #' @family archivist
 #' @rdname asearch
 #' @export
-asearch <- function( repo, patterns){
-  stopifnot( is.character( repo ) )
+asearch <- function( patterns, repo = NULL){
+  stopifnot( is.character( repo ) | is.null(repo) )
   stopifnot( is.character( patterns ) )
-  
-  # at least 3 elements
-  elements <- strsplit(repo, "/")[[1]]
-  stopifnot( length(elements) >= 2 )
 
-  oblist <- multiSearchInGithubRepo(user = elements[1], repo=paste(elements[-1], collapse = "/"), 
-                                 patterns = patterns,
-                                 intersect = TRUE)
   res <- list()
-  if (length(oblist)>0) {
-     res <- lapply(paste0(repo, "/", oblist), aread)
+  if (is.null(repo)) {
+    # use default repo
+    oblist <- multiSearchInLocalRepo(patterns = patterns,
+                                      intersect = TRUE)
+    if (length(oblist)>0) {
+      res <- lapply(oblist, aread)
+    } 
+  } else {
+    # at least 3 elements
+    # it's GitHub Repo
+    elements <- strsplit(repo, "/")[[1]]
+    stopifnot( length(elements) >= 2 )
+    
+    oblist <- multiSearchInGithubRepo(user = elements[1], repo=paste(elements[-1], collapse = "/"), 
+                                      patterns = patterns,
+                                      intersect = TRUE)
+    if (length(oblist)>0) {
+      res <- lapply(paste0(repo, "/", oblist), aread)
+    } 
   } 
   res
 }
